@@ -299,7 +299,7 @@ class Quantity:
                 self._data = data.gpu_view
             elif isinstance(data, gt4py.storage.storage.CPUStorage):
                 self._storage = data
-                self._data = np.asarray(data)
+                self._data = data.data
             else:
                 raise TypeError(
                     "only storages supported are CPUStorage and GPUStorage, "
@@ -421,7 +421,7 @@ class Quantity:
         # when GDP-3 is merged, we can instead use the data in self._data to
         # initialize the storage, instead of making a copy.
         if isinstance(storage, gt4py.storage.storage.CPUStorage):
-            data = np.asarray(storage.data)
+            data = storage.data
         elif isinstance(storage, gt4py.storage.storage.GPUStorage):
             data = storage.gpu_view
         else:
@@ -523,7 +523,7 @@ class Quantity:
         """
         target_dims = _collapse_dims(target_dims, self.dims)
         transpose_order = [self.dims.index(dim) for dim in target_dims]
-        return Quantity(
+        transposed = Quantity(
             self.np.transpose(self.data, transpose_order),  # type: ignore[attr-defined]
             dims=transpose_sequence(self.dims, transpose_order),
             units=self.units,
@@ -531,6 +531,8 @@ class Quantity:
             extent=transpose_sequence(self.extent, transpose_order),
             gt4py_backend=self.gt4py_backend,
         )
+        transposed._attrs = self._attrs
+        return transposed
 
 
 def transpose_sequence(sequence, order):
