@@ -19,28 +19,20 @@ def layout(request, fast):
         return request.param
 
 
-@pytest.fixture
-def nx_rank(n_points):
-    return max(3, n_points * 2 - 1)
-
-
-@pytest.fixture
-def ny_rank(nx_rank):
-    return nx_rank
-
-
 @pytest.fixture
 def nz():
     return 2
 
 
 @pytest.fixture
-def ny(ny_rank, layout):
+def ny(n_points, layout):
+    ny_rank = max(12, n_points * 2 - 1)
     return ny_rank * layout[0]
 
 
 @pytest.fixture
-def nx(nx_rank, layout):
+def nx(n_points, layout):
+    nx_rank = max(12, n_points * 2 - 1)
     return nx_rank * layout[1]
 
 
@@ -167,7 +159,7 @@ def extent(n_points, dims, nz, ny, nx):
 
 
 @pytest.fixture
-def communicator_list(cube_partitioner):
+def communicator_list(cube_partitioner, total_ranks):
     shared_buffer = {}
     return_list = []
     for rank in range(cube_partitioner.total_ranks):
@@ -183,9 +175,14 @@ def communicator_list(cube_partitioner):
     return return_list
 
 
+@pytest.fixture(params=[0.1, 1.0])
+def edge_interior_ratio(request):
+    return request.param
+
+
 @pytest.fixture
-def tile_partitioner(layout):
-    return pace.util.TilePartitioner(layout)
+def tile_partitioner(layout, edge_interior_ratio: float):
+    return pace.util.TilePartitioner(layout, edge_interior_ratio=edge_interior_ratio)
 
 
 @pytest.fixture
